@@ -6,8 +6,6 @@
 
 #pragma once
 
-#include "powerdevilbackendinterface.h"
-
 #include <QPointer>
 #include <QSet>
 #include <QStringList>
@@ -21,10 +19,12 @@
 
 #include <KSharedConfig>
 
-#include "batterycontroller.h"
-#include "lidcontroller.h"
+#include "controllers/batterycontroller.h"
+#include "controllers/keyboardbrightnesscontroller.h"
+#include "controllers/lidcontroller.h"
+#include "controllers/screenbrightnesscontroller.h"
+#include "controllers/suspendcontroller.h"
 #include "powerdevilcore_export.h"
-#include "suspendcontroller.h"
 
 namespace KActivities
 {
@@ -42,7 +42,6 @@ class Battery;
 
 namespace PowerDevil
 {
-class BackendInterface;
 class Action;
 class GlobalSettings;
 
@@ -78,21 +77,23 @@ public:
 
     bool emitBatteryChargePercentNotification(int currentPercent, int previousPercent, const QString &udi = QString(), ChargeNotificationFlags flags = {});
 
-    BackendInterface *backend();
     SuspendController *suspendController();
     BatteryController *batteryController();
     LidController *lidController();
+    KeyboardBrightnessController *keyboardBrightnessController();
+    ScreenBrightnessController *screenBrightnessController();
 
     Action *action(const QString actionId);
 
     // More...
 
 public Q_SLOTS:
-    void loadCore(PowerDevil::BackendInterface *backend);
+    void loadCore();
     // Set of common action - useful for the DBus interface
     uint backendCapabilities();
     void refreshStatus();
     void reparseConfiguration();
+    void onControllersReady();
 
     QString currentProfile() const;
     void loadProfile(bool force = false);
@@ -104,6 +105,7 @@ public Q_SLOTS:
     bool isLidPresent() const;
     bool isActionSupported(const QString &actionName);
     bool hasDualGpu() const;
+    bool isBatteryConservationModeEnabled() const;
     int chargeStartThreshold() const;
     int chargeStopThreshold() const;
 
@@ -122,6 +124,7 @@ Q_SIGNALS:
     void batteryRemainingTimeChanged(qulonglong time);
     void smoothedBatteryRemainingTimeChanged(qulonglong time);
     void lidClosedChanged(bool closed);
+    void batteryConservationModeChanged(bool enabled);
     void chargeStartThresholdChanged(int threshold);
     void chargeStopThresholdChanged(int threshold);
 
@@ -136,6 +139,7 @@ private:
     void triggerCriticalBatteryAction();
 
     void readChargeThreshold();
+    void readBatteryConservationMode();
 
     /**
      * Computes the current global charge percentage.
@@ -146,13 +150,15 @@ private:
     friend class Action;
 
     bool m_hasDualGpu;
+    bool m_batteryConservationModeEnabled = false;
     int m_chargeStartThreshold = 0;
     int m_chargeStopThreshold = 100;
 
-    BackendInterface *m_backend = nullptr;
     std::unique_ptr<SuspendController> m_suspendController;
     std::unique_ptr<BatteryController> m_batteryController;
     std::unique_ptr<LidController> m_lidController;
+    std::unique_ptr<KeyboardBrightnessController> m_keyboardBrightnessController;
+    std::unique_ptr<ScreenBrightnessController> m_screenBrightnessController;
 
     QDBusServiceWatcher *m_notificationsWatcher = nullptr;
     bool m_notificationsReady = false;
@@ -190,7 +196,6 @@ private:
     QStringList m_activeActions;
 
 private Q_SLOTS:
-    void onBackendReady();
     void onAcAdapterStateChanged(BatteryController::AcAdapterState);
     void onBatteryChargePercentChanged(int, const QString &);
     void onBatteryChargeStateChanged(int, const QString &);
